@@ -154,53 +154,25 @@ void CameraUI::Make_Retrans_Request(){
 offset specifies the offset of img's top-left corner relative to the ORIGINAL image's CENTER pixel */
 void CameraUI::CorrectVignetting(QImage * img, QPoint offset){
 
-    /* Debug stuff */
-    QString debug_tif_filename;
-    if(DEBUG){
-        int existing_debug_tifs_count = 0;
-        while(true){
-            debug_tif_filename.sprintf("%03d", existing_debug_tifs_count);
-            debug_tif_filename = QDir::homePath() + "/cs262a_debug/" + debug_tif_filename;
-            if(!QFile::exists(debug_tif_filename + ".tif")){
-                break;
-            }else{
-                existing_debug_tifs_count++;
-            }
-        }
-        QImage no_correction_img(*img);
-        no_correction_img = ConvertToGrayScale(no_correction_img);
-        bool saved = no_correction_img.save(debug_tif_filename + ".tif");
-    }
-    /* End debug stuff */
-
     // Iterate through every pixel in img and apply the correction
-    for(int x = 0; x < img->width(); x++){
-        for(int y = 0; y < img->height(); y++){
-            int manhattan_distance = abs(x + offset.x()) + abs(y + offset.y());
-            float scale_by = pow((float)manhattan_distance, 2) * 0.0000002 + 0.00007 * manhattan_distance - 0.0483;
-            QColor oldPixelColor = QColor::fromRgb(img->pixel(x, y));
+    for(int y = 0; y < img->height(); y++){
+        QRgb* line = (QRgb*) img->scanLine(y);
+        for(int x = 0; x < img->width(); x++){
+            float scale_by = vigProfile[x][y];
+
+            QColor oldPixelColor = QColor::fromRgb(*(line + x));
 
             // Don't change the pixel color if it's darker than the original. Clip pixel value at 255.
             int new_value = oldPixelColor.value() * (1 + scale_by);
-            if(new_value < oldPixelColor.value()){
-                new_value = oldPixelColor.value();
-            }else if(new_value > 255){
+
+            if(new_value > 255){
                 new_value = 255;
             }
-            // Scale up to the new V (HSV)
-            QColor newPixelColor = QColor::fromHsv(oldPixelColor.hue(), oldPixelColor.saturation(), new_value);
-            img->setPixel(x, y, newPixelColor.rgb());
+
+            oldPixelColor.setHsv(oldPixelColor.hue(), oldPixelColor.saturation(), new_value);
+            *(line + x) = oldPixelColor.rgb();
         }
     }
-
-    /* Debug stuff */
-    if(DEBUG){
-        QImage corrected_img(*img);
-        corrected_img = ConvertToGrayScale(corrected_img);
-        bool saved = corrected_img.save(debug_tif_filename + "_corrected.tif");
-    }
-    /* End Debug stuff */
-
 }
 
 // Convert the img to grayscale, return a new img
@@ -374,6 +346,22 @@ void CameraUI::ParseOCRdText(){
     }
 }
 
+void CameraUI::LoadVigProfile(){
+    QFile file(QDir::homePath() + QString("/.mir-translator/vignettefactors"));
+    file.open(QIODevice::ReadOnly);
+    QDataStream in(&file);    // read the data serialized from the file
+
+    float val;
+    for(int i = 0; i < 1944; i++){
+        vigProfile.append(QList<float>());
+        for(int j = 0; j < 2560; j++){
+            in >> val;
+            vigProfile[i].append(val);
+        }
+    }
+    file.close();
+}
+
 // Called when then send button is pressed
 void CameraUI::send() {
     langMode = sourceCBox->currentText();
