@@ -127,6 +127,7 @@ public:
         connect(retransButton, SIGNAL(clicked()), this, SLOT(Make_Retrans_Request()));
 
         resegmentDialog = 0;
+        LoadVigProfile();
     }
 
 
@@ -200,6 +201,9 @@ private:
     bool retransEnabled;
     QTextCursor oldTextCursor;
 
+    //VigProfile
+    QList<QList<float> > vigProfile;
+
     void updateResultView(){
         int pos = resultView->textCursor().selectionEnd();
 
@@ -276,6 +280,7 @@ public slots:
     void ShowErrorConnectingDialog(OCRRequest *req);
     void ShowNoResultsDialog();
     void QuitApp();
+    void LoadVigProfile();
 
 
 signals:
