@@ -101,6 +101,8 @@ int LangToInt(QString lang){
         return 35;
     }else if(lang == "Vietnamese"){
         return 36;
+    }else if(lang == "Hindi"){
+        return 37;
     }
     return 0;
 }
@@ -181,6 +183,8 @@ QString IntToLang(int i){
         return "ukr";
     case 36:
         return "view";
+    case 37:
+        return "hin";
     }
     return 0;
 }
